Overview
--------

Ralph is an asset management system for your data center.  It lets you see what
hardware and software is installed. It also lets you keep track of who is using
every device, for what, and how much it costs.

Ralph's database can be accessed through a web interface, a RESTful API and
through command line tools, the most important of which is the discovery
command, which lets Ralph gather information about your data center
automatically. You can also export and import parts of the database into
different formats.

